/* { dg-do compile } */
#include <altivec.h>
typedef	unsigned long	size_t;
vector signed int T_vec_s32;
void *T_void_ptr;
const void *T_const_void_ptr;
size_t T_size_t;
char *T_char_ptr;
vector signed short T_vec_s16;
vector signed char T_vec_s8;
vector unsigned short T_vec_u16;
vector unsigned int T_vec_u32;
vector unsigned char T_vec_u8;
vector float T_vec_f32;
int T_int;
float *T_float_ptr;
void f(void);
short *T_short_ptr;
vector signed short *T_vec_s16_ptr;
int *T_int_ptr;
vector signed int *T_vec_s32_ptr;
signed char *T_signed_char_ptr;
vector signed char *T_vec_s8_ptr;
unsigned short *T_unsigned_short_ptr;
vector unsigned short *T_vec_u16_ptr;
unsigned int *T_unsigned_int_ptr;
vector unsigned int *T_vec_u32_ptr;
unsigned char *T_unsigned_char_ptr;
vector unsigned char *T_vec_u8_ptr;
double T_double;
int T_intb;
vector bool short *T_vec_b16_ptr;
vector bool int *T_vec_b32_ptr;
vector bool char *T_vec_b8_ptr;
vector float *T_vec_f32_ptr;
vector pixel *T_vec_p16_ptr;
vector bool short T_vec_b16;
vector pixel T_vec_p16;
vector bool int T_vec_b32;
vector bool char T_vec_b8;
float T_float;
volatile void g(void);
const char *T_const_char_ptr;
