-- C87B43A.ADA

--                             Grant of Unlimited Rights
--
--     Under contracts F33600-87-D-0337, F33600-84-D-0280, MDA903-79-C-0687,
--     F08630-91-C-0015, and DCA100-97-D-0025, the U.S. Government obtained 
--     unlimited rights in the software and documentation contained herein.
--     Unlimited rights are defined in DFAR 252.227-7013(a)(19).  By making 
--     this public release, the Government intends to confer upon all 
--     recipients unlimited rights  equal to those held by the Government.  
--     These rights include rights to use, duplicate, release or disclose the 
--     released technical data and computer software in whole or in part, in 
--     any manner and for any purpose whatsoever, and to have or permit others 
--     to do so.
--
--                                    DISCLAIMER
--
--     ALL MATERIALS OR INFORMATION HEREIN RELEASED, MADE AVAILABLE OR
--     DISCLOSED ARE AS IS.  THE GOVERNMENT MAKES NO EXPRESS OR IMPLIED 
--     WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING THE CONDITIONS OF THE
--     SOFTWARE, DOCUMENTATION OR OTHER INFORMATION RELEASED, MADE AVAILABLE 
--     OR DISCLOSED, OR THE OWNERSHIP, MERCHANTABILITY, OR FITNESS FOR A
--     PARTICULAR PURPOSE OF SAID MATERIAL.
--*
-- CHECK THAT OVERLOADING RESOLUTION USES THE RULE THAT:
--
-- IN A CASE STATEMENT, THE TYPE OF EACH CHOICE MUST MATCH THE TYPE 
-- OF THE EXPRESSION.
  
-- TRH  3 AUG 82
-- DSJ 10 JUN 83
  
WITH REPORT; USE REPORT;
   
PROCEDURE C87B43A IS
     
     TYPE WHOLE IS NEW INTEGER RANGE 0 .. INTEGER'LAST;
 
     FUNCTION "+" (X, Y : INTEGER) RETURN INTEGER 
          RENAMES "*";
 
     ERR : BOOLEAN := FALSE;
     X   : WHOLE   := 6;
  
BEGIN
     TEST ("C87B43A","TYPE OF CASE CHOICE MUST MATCH TYPE OF " &
           "EXPRESSION");
   
     CASE X IS
          WHEN (2 + 3) => ERR := TRUE;
          WHEN (3 + 3) => NULL; 
          WHEN OTHERS  => ERR := TRUE;
     END CASE;
 
     IF ERR THEN
        FAILED ("CASE STATEMENT CHOICE MUST MATCH TYPE OF EXPRESSION");
     END IF;
    
     RESULT;
END C87B43A;
